@@ -85,10 +85,7 @@ def get_explanation(model, inputs, targets, **kwargs):
 
 
 def generate_tf_explanation(
-    model: tf.keras.Model, 
-    inputs: np.array, 
-    targets: np.array, 
-    **kwargs
+    model: tf.keras.Model, inputs: np.array, targets: np.array, **kwargs
 ) -> np.ndarray:
     """
     Generate explanation for a tf model with tf_explain.
