@@ -1,5 +1,8 @@
 """This module contains the collection of complexity metrics to evaluate attribution-based explanations of neural network models."""
 from typing import Union, List, Dict
+from tqdm import tqdm
+
+
 from .base import Metric
 from ..helpers.utils import *
 from ..helpers.asserts import *
@@ -43,6 +46,7 @@ class Sparseness(Metric):
             default=normalise_by_negative.
             default_plot_func (callable): Callable that plots the metrics result.
             disable_warnings (boolean): Indicates whether the warnings are printed, default=False.
+            display_progressbar (boolean): Indicates whether a tqdm-progress-bar is printed, default=False.
         """
         super().__init__()
 
@@ -53,6 +57,7 @@ class Sparseness(Metric):
         self.normalise_func = self.kwargs.get("normalise_func", normalise_by_negative)
         self.default_plot_func = Callable
         self.disable_warnings = self.kwargs.get("disable_warnings", False)
+        self.display_progressbar = self.kwargs.get("display_progressbar", False)
         self.last_results = []
         self.all_results = []
 
@@ -131,7 +136,8 @@ class Sparseness(Metric):
         # Reshape input batch to channel first order:
         self.channel_first = kwargs.get("channel_first", get_channel_first(x_batch))
         x_batch_s = get_channel_first_batch(x_batch, self.channel_first)
-        # Wrap the model into an interface
+
+        # Wrap the model into an interface.
         if model:
             model = get_wrapped_model(model, self.channel_first)
 
@@ -161,7 +167,13 @@ class Sparseness(Metric):
         # Asserts.
         assert_attributions(x_batch=x_batch_s, a_batch=a_batch)
 
-        for x, y, a in zip(x_batch_s, y_batch, a_batch):
+        # use tqdm progressbar if not disabled
+        if not self.display_progressbar:
+            iterator = zip(x_batch_s, y_batch, a_batch)
+        else:
+            iterator = tqdm(zip(x_batch_s, y_batch, a_batch), total=len(x_batch_s))
+
+        for x, y, a in iterator:
 
             a = a.flatten()
 
@@ -221,6 +233,7 @@ class Complexity(Metric):
             default=normalise_by_negative.
             default_plot_func (callable): Callable that plots the metrics result.
             disable_warnings (boolean): Indicates whether the warnings are printed, default=False.
+            display_progressbar (boolean): Indicates whether a tqdm-progress-bar is printed, default=False.
         """
         super().__init__()
 
@@ -231,6 +244,7 @@ class Complexity(Metric):
         self.normalise_func = self.kwargs.get("normalise_func", normalise_by_negative)
         self.default_plot_func = Callable
         self.disable_warnings = self.kwargs.get("disable_warnings", False)
+        self.display_progressbar = self.kwargs.get("display_progressbar", False)
         self.last_results = []
         self.all_results = []
 
@@ -308,7 +322,8 @@ class Complexity(Metric):
         # Reshape input batch to channel first order:
         self.channel_first = kwargs.get("channel_first", get_channel_first(x_batch))
         x_batch_s = get_channel_first_batch(x_batch, self.channel_first)
-        # Wrap the model into an interface
+
+        # Wrap the model into an interface.
         if model:
             model = get_wrapped_model(model, self.channel_first)
 
@@ -338,7 +353,13 @@ class Complexity(Metric):
         # Asserts.
         assert_attributions(x_batch=x_batch_s, a_batch=a_batch)
 
-        for x, y, a in zip(x_batch_s, y_batch, a_batch):
+        # use tqdm progressbar if not disabled
+        if not self.display_progressbar:
+            iterator = zip(x_batch_s, y_batch, a_batch)
+        else:
+            iterator = tqdm(zip(x_batch_s, y_batch, a_batch), total=len(x_batch_s))
+
+        for x, y, a in iterator:
 
             if self.abs:
                 a = np.abs(a)
@@ -352,13 +373,10 @@ class Complexity(Metric):
             if self.normalise:
                 a = self.normalise_func(a)
 
-            a = (
-                np.array(
-                    np.reshape(a, (self.img_size * self.img_size,)),
-                    dtype=np.float64,
-                )
-                / np.sum(np.abs(a))
-            )
+            a = np.array(
+                np.reshape(a, (self.img_size * self.img_size,)),
+                dtype=np.float64,
+            ) / np.sum(np.abs(a))
 
             self.last_results.append(scipy.stats.entropy(pk=a))
 
@@ -393,6 +411,7 @@ class EffectiveComplexity(Metric):
             default=normalise_by_negative.
             default_plot_func (callable): Callable that plots the metrics result.
             disable_warnings (boolean): Indicates whether the warnings are printed, default=False.
+            display_progressbar (boolean): Indicates whether a tqdm-progress-bar is printed, default=False.
         """
         super().__init__()
 
@@ -404,6 +423,7 @@ class EffectiveComplexity(Metric):
         self.normalise_func = self.kwargs.get("normalise_func", normalise_by_negative)
         self.default_plot_func = Callable
         self.disable_warnings = self.kwargs.get("disable_warnings", False)
+        self.display_progressbar = self.kwargs.get("display_progressbar", False)
         self.last_results = []
         self.all_results = []
 
@@ -481,7 +501,8 @@ class EffectiveComplexity(Metric):
         # Reshape input batch to channel first order:
         self.channel_first = kwargs.get("channel_first", get_channel_first(x_batch))
         x_batch_s = get_channel_first_batch(x_batch, self.channel_first)
-        # Wrap the model into an interface
+
+        # Wrap the model into an interface.
         if model:
             model = get_wrapped_model(model, self.channel_first)
 
@@ -511,7 +532,13 @@ class EffectiveComplexity(Metric):
         # Asserts.
         assert_attributions(x_batch=x_batch_s, a_batch=a_batch)
 
-        for x, y, a in zip(x_batch_s, y_batch, a_batch):
+        # use tqdm progressbar if not disabled
+        if not self.display_progressbar:
+            iterator = zip(x_batch_s, y_batch, a_batch)
+        else:
+            iterator = tqdm(zip(x_batch_s, y_batch, a_batch), total=len(x_batch_s))
+
+        for x, y, a in iterator:
 
             a = a.flatten()
 
