@@ -1,8 +1,11 @@
 """This module contains the collection of localisation metrics to evaluate attribution-based explanations of neural network models."""
-import warnings
-import numpy as np
 from typing import Union, List, Dict
+import warnings
+
+import numpy as np
 from sklearn.metrics import roc_curve, auc
+from tqdm import tqdm
+
 from .base import Metric
 from ..helpers.utils import *
 from ..helpers.asserts import *
@@ -43,6 +46,7 @@ class PointingGame(Metric):
             default=normalise_by_negative.
             default_plot_func (callable): Callable that plots the metrics result.
             disable_warnings (boolean): Indicates whether the warnings are printed, default=False.
+            display_progressbar (boolean): Indicates whether a tqdm-progress-bar is printed, default=False.
         """
         super().__init__()
 
@@ -53,6 +57,7 @@ class PointingGame(Metric):
         self.normalise_func = self.kwargs.get("normalise_func", normalise_by_negative)
         self.default_plot_func = Callable
         self.disable_warnings = self.kwargs.get("disable_warnings", False)
+        self.display_progressbar = self.kwargs.get("display_progressbar", False)
         self.last_results = []
         self.all_results = []
 
@@ -134,7 +139,8 @@ class PointingGame(Metric):
         # Reshape input batch to channel first order:
         self.channel_first = kwargs.get("channel_first", get_channel_first(x_batch))
         x_batch_s = get_channel_first_batch(x_batch, self.channel_first)
-        # Wrap the model into an interface
+
+        # Wrap the model into an interface.
         if model:
             model = get_wrapped_model(model, self.channel_first)
 
@@ -165,9 +171,16 @@ class PointingGame(Metric):
         assert_attributions(x_batch=x_batch_s, a_batch=a_batch)
         assert_segmentations(x_batch=x_batch_s, s_batch=s_batch)
 
-        for sample, (x, y, a, s) in enumerate(
-            zip(x_batch_s, y_batch, a_batch, s_batch)
-        ):
+        # use tqdm progressbar if not disabled
+        if not self.display_progressbar:
+            iterator = enumerate(zip(x_batch_s, y_batch, a_batch, s_batch))
+        else:
+            iterator = tqdm(
+                enumerate(zip(x_batch_s, y_batch, a_batch, s_batch)),
+                total=len(x_batch_s),
+            )
+
+        for ix, (x, y, a, s) in iterator:
 
             # Reshape.
             a = a.flatten()
@@ -230,6 +243,7 @@ class AttributionLocalisation(Metric):
             default=normalise_by_negative.
             default_plot_func (callable): Callable that plots the metrics result.
             disable_warnings (boolean): Indicates whether the warnings are printed, default=False.
+            display_progressbar (boolean): Indicates whether a tqdm-progress-bar is printed, default=False.
         """
         super().__init__()
 
@@ -242,6 +256,7 @@ class AttributionLocalisation(Metric):
         self.normalise_func = self.kwargs.get("normalise_func", normalise_by_negative)
         self.default_plot_func = Callable
         self.disable_warnings = self.kwargs.get("disable_warnings", False)
+        self.display_progressbar = self.kwargs.get("display_progressbar", False)
         self.last_results = []
         self.all_results = []
 
@@ -325,7 +340,8 @@ class AttributionLocalisation(Metric):
         # Reshape input batch to channel first order:
         self.channel_first = kwargs.get("channel_first", get_channel_first(x_batch))
         x_batch_s = get_channel_first_batch(x_batch, self.channel_first)
-        # Wrap the model into an interface
+
+        # Wrap the model into an interface.
         if model:
             model = get_wrapped_model(model, self.channel_first)
 
@@ -355,9 +371,16 @@ class AttributionLocalisation(Metric):
         assert_attributions(x_batch=x_batch_s, a_batch=a_batch)
         assert_segmentations(x_batch=x_batch_s, s_batch=s_batch)
 
-        for sample, (x, y, a, s) in enumerate(
-            zip(x_batch_s, y_batch, a_batch, s_batch)
-        ):
+        # use tqdm progressbar if not disabled
+        if not self.display_progressbar:
+            iterator = enumerate(zip(x_batch_s, y_batch, a_batch, s_batch))
+        else:
+            iterator = tqdm(
+                enumerate(zip(x_batch_s, y_batch, a_batch, s_batch)),
+                total=len(x_batch_s),
+            )
+
+        for ix, (x, y, a, s) in iterator:
 
             a = a.flatten()
             s = s.flatten().astype(bool)
@@ -441,6 +464,7 @@ class TopKIntersection(Metric):
             default=normalise_by_negative.
             default_plot_func (callable): Callable that plots the metrics result.
             disable_warnings (boolean): Indicates whether the warnings are printed, default=False.
+            display_progressbar (boolean): Indicates whether a tqdm-progress-bar is printed, default=False.
         """
         super().__init__()
 
@@ -453,6 +477,7 @@ class TopKIntersection(Metric):
         self.normalise_func = self.kwargs.get("normalise_func", normalise_by_negative)
         self.default_plot_func = Callable
         self.disable_warnings = self.kwargs.get("disable_warnings", False)
+        self.display_progressbar = self.kwargs.get("display_progressbar", False)
         self.last_results = []
         self.all_results = []
 
@@ -535,7 +560,8 @@ class TopKIntersection(Metric):
         # Reshape input batch to channel first order:
         self.channel_first = kwargs.get("channel_first", get_channel_first(x_batch))
         x_batch_s = get_channel_first_batch(x_batch, self.channel_first)
-        # Wrap the model into an interface
+
+        # Wrap the model into an interface.
         if model:
             model = get_wrapped_model(model, self.channel_first)
 
@@ -566,9 +592,16 @@ class TopKIntersection(Metric):
         assert_attributions(x_batch=x_batch_s, a_batch=a_batch)
         assert_segmentations(x_batch=x_batch_s, s_batch=s_batch)
 
-        for sample, (x, y, a, s) in enumerate(
-            zip(x_batch_s, y_batch, a_batch, s_batch)
-        ):
+        # use tqdm progressbar if not disabled
+        if not self.display_progressbar:
+            iterator = enumerate(zip(x_batch_s, y_batch, a_batch, s_batch))
+        else:
+            iterator = tqdm(
+                enumerate(zip(x_batch_s, y_batch, a_batch, s_batch)),
+                total=len(x_batch_s),
+            )
+
+        for ix, (x, y, a, s) in iterator:
 
             if self.abs:
                 a = np.abs(a)
@@ -628,6 +661,7 @@ class RelevanceRankAccuracy(Metric):
             default=normalise_by_negative.
             default_plot_func (callable): Callable that plots the metrics result.
             disable_warnings (boolean): Indicates whether the warnings are printed, default=False.
+            display_progressbar (boolean): Indicates whether a tqdm-progress-bar is printed, default=False.
         """
         super().__init__()
 
@@ -638,6 +672,7 @@ class RelevanceRankAccuracy(Metric):
         self.normalise_func = self.kwargs.get("normalise_func", normalise_by_negative)
         self.default_plot_func = Callable
         self.disable_warnings = self.kwargs.get("disable_warnings", False)
+        self.display_progressbar = self.kwargs.get("display_progressbar", False)
         self.last_results = []
         self.all_results = []
 
@@ -719,7 +754,8 @@ class RelevanceRankAccuracy(Metric):
         # Reshape input batch to channel first order:
         self.channel_first = kwargs.get("channel_first", get_channel_first(x_batch))
         x_batch_s = get_channel_first_batch(x_batch, self.channel_first)
-        # Wrap the model into an interface
+
+        # Wrap the model into an interface.
         if model:
             model = get_wrapped_model(model, self.channel_first)
 
@@ -750,9 +786,16 @@ class RelevanceRankAccuracy(Metric):
         assert_attributions(x_batch=x_batch_s, a_batch=a_batch)
         assert_segmentations(x_batch=x_batch_s, s_batch=s_batch)
 
-        for sample, (x, y, a, s) in enumerate(
-            zip(x_batch_s, y_batch, a_batch, s_batch)
-        ):
+        # use tqdm progressbar if not disabled
+        if not self.display_progressbar:
+            iterator = enumerate(zip(x_batch_s, y_batch, a_batch, s_batch))
+        else:
+            iterator = tqdm(
+                enumerate(zip(x_batch_s, y_batch, a_batch, s_batch)),
+                total=len(x_batch_s),
+            )
+
+        for ix, (x, y, a, s) in iterator:
 
             a = a.flatten()
             s = np.where(s.flatten().astype(bool))[0]
@@ -816,6 +859,7 @@ class RelevanceMassAccuracy(Metric):
             default=normalise_by_negative.
             default_plot_func (callable): Callable that plots the metrics result.
             disable_warnings (boolean): Indicates whether the warnings are printed, default=False.
+            display_progressbar (boolean): Indicates whether a tqdm-progress-bar is printed, default=False.
         """
         super().__init__()
 
@@ -826,6 +870,7 @@ class RelevanceMassAccuracy(Metric):
         self.normalise_func = self.kwargs.get("normalise_func", normalise_by_negative)
         self.default_plot_func = Callable
         self.disable_warnings = self.kwargs.get("disable_warnings", False)
+        self.display_progressbar = self.kwargs.get("display_progressbar", False)
         self.last_results = []
         self.all_results = []
 
@@ -906,7 +951,8 @@ class RelevanceMassAccuracy(Metric):
         # Reshape input batch to channel first order:
         self.channel_first = kwargs.get("channel_first", get_channel_first(x_batch))
         x_batch_s = get_channel_first_batch(x_batch, self.channel_first)
-        # Wrap the model into an interface
+
+        # Wrap the model into an interface.
         if model:
             model = get_wrapped_model(model, self.channel_first)
 
@@ -937,9 +983,16 @@ class RelevanceMassAccuracy(Metric):
         assert_attributions(x_batch=x_batch_s, a_batch=a_batch)
         assert_segmentations(x_batch=x_batch_s, s_batch=s_batch)
 
-        for sample, (x, y, a, s) in enumerate(
-            zip(x_batch_s, y_batch, a_batch, s_batch)
-        ):
+        # use tqdm progressbar if not disabled
+        if not self.display_progressbar:
+            iterator = enumerate(zip(x_batch_s, y_batch, a_batch, s_batch))
+        else:
+            iterator = tqdm(
+                enumerate(zip(x_batch_s, y_batch, a_batch, s_batch)),
+                total=len(x_batch_s),
+            )
+
+        for ix, (x, y, a, s) in iterator:
 
             a = a.flatten()
 
@@ -997,6 +1050,7 @@ class AUC(Metric):
             default=normalise_by_negative.
             default_plot_func (callable): Callable that plots the metrics result.
             disable_warnings (boolean): Indicates whether the warnings are printed, default=False.
+            display_progressbar (boolean): Indicates whether a tqdm-progress-bar is printed, default=False.
         """
         super().__init__()
 
@@ -1007,6 +1061,7 @@ class AUC(Metric):
         self.normalise_func = self.kwargs.get("normalise_func", normalise_by_negative)
         self.default_plot_func = Callable
         self.disable_warnings = self.kwargs.get("disable_warnings", False)
+        self.display_progressbar = self.kwargs.get("display_progressbar", False)
         self.last_results = []
         self.all_results = []
 
@@ -1086,7 +1141,8 @@ class AUC(Metric):
         # Reshape input batch to channel first order:
         self.channel_first = kwargs.get("channel_first", get_channel_first(x_batch))
         x_batch_s = get_channel_first_batch(x_batch, self.channel_first)
-        # Wrap the model into an interface
+
+        # Wrap the model into an interface.
         if model:
             model = get_wrapped_model(model, self.channel_first)
 
@@ -1117,9 +1173,16 @@ class AUC(Metric):
         assert_attributions(x_batch=x_batch_s, a_batch=a_batch)
         assert_segmentations(x_batch=x_batch_s, s_batch=s_batch)
 
-        for sample, (x, y, a, s) in enumerate(
-            zip(x_batch_s, y_batch, a_batch, s_batch)
-        ):
+        # use tqdm progressbar if not disabled
+        if not self.display_progressbar:
+            iterator = enumerate(zip(x_batch_s, y_batch, a_batch, s_batch))
+        else:
+            iterator = tqdm(
+                enumerate(zip(x_batch_s, y_batch, a_batch, s_batch)),
+                total=len(x_batch_s),
+            )
+
+        for ix, (x, y, a, s) in iterator:
 
             if self.abs:
                 a = np.abs(a)
