@@ -1,7 +1,10 @@
 """This module contains the collection of randomisation metrics to evaluate attribution-based explanations of neural network models."""
-import numpy as np
 import random
 from typing import Union, List, Dict
+
+import numpy as np
+from tqdm import tqdm
+
 from .base import Metric
 from ..helpers.utils import *
 from ..helpers.asserts import *
@@ -44,6 +47,7 @@ class ModelParameterRandomisation(Metric):
             default=normalise_by_negative.
             default_plot_func (callable): Callable that plots the metrics result.
             disable_warnings (boolean): Indicates whether the warnings are printed, default=False.
+            display_progressbar (boolean): Indicates whether a tqdm-progress-bar is printed, default=False.
             similarity_func (callable): Similarity function applied to compare input and perturbed input,
             default=correlation_spearman.
             layer_order (string): Indicated whether the model is randomized cascadingly or independently.
@@ -59,8 +63,10 @@ class ModelParameterRandomisation(Metric):
         self.normalise_func = self.kwargs.get("normalise_func", normalise_by_negative)
         self.default_plot_func = Callable
         self.disable_warnings = self.kwargs.get("disable_warnings", False)
+        self.display_progressbar = self.kwargs.get("display_progressbar", False)
         self.similarity_func = self.kwargs.get("similarity_func", correlation_spearman)
         self.layer_order = kwargs.get("layer_order", "independent")
+        self.seed = self.kwargs.get("seed", 42)
         self.last_results = {}
         self.all_results = []
 
@@ -138,7 +144,8 @@ class ModelParameterRandomisation(Metric):
         # Reshape input batch to channel first order:
         self.channel_first = kwargs.get("channel_first", get_channel_first(x_batch))
         x_batch_s = get_channel_first_batch(x_batch, self.channel_first)
-        # Wrap the model into an interface
+
+        # Wrap the model into an interface.
         if model:
             model = get_wrapped_model(model, self.channel_first)
 
@@ -168,8 +175,18 @@ class ModelParameterRandomisation(Metric):
         # Asserts.
         assert_attributions(x_batch=x_batch_s, a_batch=a_batch)
 
+        # Create progress bar if desired.
+        # Due to the nested for-loops and the requirement of a single progressbar,
+        # manual updating will be performed at the end of each inner iteration.
+        if self.display_progressbar:
+            n_layers = len(
+                list(model.get_random_layer_generator(order=self.layer_order))
+            )
+            n_iterations = n_layers * len(a_batch)
+            pbar = tqdm(total=n_iterations)
+
         for layer_name, random_layer_model in model.get_random_layer_generator(
-            order=self.layer_order
+            order=self.layer_order, seed=self.seed
         ):
 
             similarity_scores = []
@@ -179,7 +196,7 @@ class ModelParameterRandomisation(Metric):
                 model=random_layer_model, inputs=x_batch, targets=y_batch, **self.kwargs
             )
 
-            for sample, (a, a_per) in enumerate(zip(a_batch, a_perturbed)):
+            for ix, (a, a_per) in enumerate(zip(a_batch, a_perturbed)):
 
                 if self.abs:
                     a = np.abs(a)
@@ -194,9 +211,17 @@ class ModelParameterRandomisation(Metric):
 
                 similarity_scores.append(similarity)
 
+                # Update progress bar if desired.
+                if self.display_progressbar:
+                    pbar.update(1)
+
             # Save similarity scores in a dictionary.
             self.last_results[layer_name] = similarity_scores
 
+        # Close progress bar if desired.
+        if self.display_progressbar:
+            pbar.close()
+
         self.all_results.append(self.last_results)
 
         return self.last_results
@@ -227,6 +252,7 @@ class RandomLogit(Metric):
             default=normalise_by_negative.
             default_plot_func (callable): Callable that plots the metrics result.
             disable_warnings (boolean): Indicates whether the warnings are printed, default=False.
+            display_progressbar (boolean): Indicates whether a tqdm-progress-bar is printed, default=False.
             similarity_func (callable): Similarity function applied to compare input and perturbed input,
             default=ssim.
             num_classes (integer): Number of prediction classes in the input, default=1000.
@@ -239,9 +265,11 @@ class RandomLogit(Metric):
         self.normalise = self.kwargs.get("normalise", True)
         self.default_plot_func = Callable
         self.disable_warnings = self.kwargs.get("disable_warnings", False)
+        self.display_progressbar = self.kwargs.get("display_progressbar", False)
         self.normalise_func = self.kwargs.get("normalise_func", normalise_by_negative)
         self.similarity_func = self.kwargs.get("similarity_func", ssim)
         self.num_classes = self.kwargs.get("num_classes", 1000)
+        self.seed = self.kwargs.get("seed", 42)
         self.last_results = []
         self.all_results = []
 
@@ -315,7 +343,8 @@ class RandomLogit(Metric):
         # Reshape input batch to channel first order:
         self.channel_first = kwargs.get("channel_first", get_channel_first(x_batch))
         x_batch_s = get_channel_first_batch(x_batch, self.channel_first)
-        # Wrap the model into an interface
+
+        # Wrap the model into an interface.
         if model:
             model = get_wrapped_model(model, self.channel_first)
 
@@ -344,7 +373,15 @@ class RandomLogit(Metric):
         # Asserts.
         assert_attributions(x_batch=x_batch, a_batch=a_batch)
 
-        for sample, (x, y, a) in enumerate(zip(x_batch, y_batch, a_batch)):
+        # use tqdm progressbar if not disabled
+        if not self.display_progressbar:
+            iterator = enumerate(zip(x_batch_s, y_batch, a_batch))
+        else:
+            iterator = tqdm(
+                enumerate(zip(x_batch_s, y_batch, a_batch)), total=len(x_batch_s)
+            )
+
+        for ix, (x, y, a) in iterator:
 
             if self.abs:
                 a = np.abs(a)
@@ -353,6 +390,7 @@ class RandomLogit(Metric):
                 a = self.normalise_func(a)
 
             # Randomly select off-class labels.
+            random.seed(a=self.seed)
             y_off = np.array(
                 [
                     random.choice(
