@@ -19,12 +19,13 @@ from ...quantus.helpers.pytorch_model import PyTorchModel
                 "perturb_baseline": "mean",
                 "similarity_func": correlation_spearman,
                 "normalise": True,
-                "disable_warnings": False,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
                 "max_steps_per_input": 2,
+                "disable_warnings": False,
+                "display_progressbar": False,
             },
             {"min": -1.0, "max": 1.0},
         ),
@@ -36,15 +37,33 @@ from ...quantus.helpers.pytorch_model import PyTorchModel
                 "nr_runs": 10,
                 "similarity_func": correlation_spearman,
                 "normalise": True,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
                 "a_batch_generate": False,
             },
             {"min": -1.0, "max": 1.0},
         ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "perturb_func": baseline_replacement_by_indices,
+                "nr_runs": 10,
+                "similarity_func": correlation_spearman,
+                "normalise": True,
+                "explain_func": explain,
+                "method": "Saliency",
+                "img_size": 28,
+                "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": True,
+            },
+            {"min": -1.0, "max": 1.0},
+        ),
         (
             lazy_fixture("load_mnist_model_tf"),
             lazy_fixture("load_mnist_images_tf"),
@@ -54,11 +73,12 @@ from ...quantus.helpers.pytorch_model import PyTorchModel
                 "perturb_baseline": "mean",
                 "similarity_func": correlation_spearman,
                 "normalise": True,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "IntegratedGradients",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
             },
             {"min": -1.0, "max": 1.0},
         ),
@@ -70,11 +90,12 @@ from ...quantus.helpers.pytorch_model import PyTorchModel
                 "nr_runs": 10,
                 "similarity_func": correlation_spearman,
                 "normalise": True,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "InputXGradient",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
             },
             {"min": -1.0, "max": 1.0},
         ),
@@ -125,12 +146,13 @@ def test_faithfulness_correlation(
                 "features_in_step": 28,
                 "perturb_baseline": "uniform",
                 "normalise": True,
-                "disable_warnings": False,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
                 "max_steps_per_input": 2,
+                "disable_warnings": False,
+                "display_progressbar": False,
             },
             {"min": -1.0, "max": 1.0},
         ),
@@ -142,11 +164,12 @@ def test_faithfulness_correlation(
                 "features_in_step": 28,
                 "perturb_baseline": "uniform",
                 "normalise": True,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Gradient",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
             },
             {"min": -1.0, "max": 1.0},
         ),
@@ -159,16 +182,35 @@ def test_faithfulness_correlation(
                 "perturb_baseline": "uniform",
                 "abs": True,
                 "normalise": True,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Gradient",
                 "img_size": 28,
                 "nr_channels": 1,
-                "a_batch_generate": False,
                 "max_steps_per_input": 2,
+                "disable_warnings": True,
+                "display_progressbar": False,
+                "a_batch_generate": False,
             },
             {"min": 0.0, "max": 1.0},
         ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "perturb_func": baseline_replacement_by_indices,
+                "features_in_step": 28,
+                "perturb_baseline": "uniform",
+                "normalise": True,
+                "explain_func": explain,
+                "method": "Saliency",
+                "img_size": 28,
+                "nr_channels": 1,
+                "max_steps_per_input": 2,
+                "disable_warnings": True,
+                "display_progressbar": True,
+            },
+            {"min": -1.0, "max": 1.0},
+        ),
     ],
 )
 def test_faithfulness_estimate(
@@ -216,12 +258,13 @@ def test_faithfulness_estimate(
                 "features_in_step": 28,
                 "perturb_baseline": "black",
                 "normalise": True,
-                "disable_warnings": False,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
                 "max_steps_per_input": 2,
+                "disable_warnings": False,
+                "display_progressbar": False,
             },
             {"allowed_dtypes": [True, False]},
         ),
@@ -233,11 +276,12 @@ def test_faithfulness_estimate(
                 "features_in_step": 28,
                 "perturb_baseline": "white",
                 "normalise": True,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
             },
             {"allowed_dtypes": [True, False]},
         ),
@@ -249,15 +293,34 @@ def test_faithfulness_estimate(
                 "features_in_step": 28,
                 "perturb_baseline": "mean",
                 "normalise": True,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Gradient",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
                 "a_batch_generate": False,
             },
             {"allowed_dtypes": [True, False]},
         ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "perturb_func": baseline_replacement_by_indices,
+                "features_in_step": 28,
+                "perturb_baseline": "black",
+                "normalise": True,
+                "explain_func": explain,
+                "method": "Saliency",
+                "img_size": 28,
+                "nr_channels": 1,
+                "max_steps_per_input": 2,
+                "disable_warnings": True,
+                "display_progressbar": True,
+            },
+            {"allowed_dtypes": [True, False]},
+        ),
     ],
 )
 def test_monotonicity_arya(
@@ -306,13 +369,36 @@ def test_monotonicity_arya(
                 "abs": True,
                 "perturb_baseline": "uniform",
                 "similarity_func": correlation_kendall_tau,
-                "disable_warnings": False,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
-                "a_batch_generate": False,
                 "max_steps_per_input": 2,
+                "disable_warnings": False,
+                "display_progressbar": False,
+                "a_batch_generate": False,
+            },
+            1.0,
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "eps": 1e-5,
+                "nr_samples": 10,
+                "features_in_step": 28,
+                "normalise": True,
+                "abs": True,
+                "perturb_baseline": "uniform",
+                "similarity_func": correlation_kendall_tau,
+                "explain_func": explain,
+                "method": "Saliency",
+                "img_size": 28,
+                "nr_channels": 1,
+                "max_steps_per_input": 2,
+                "disable_warnings": True,
+                "display_progressbar": True,
+                "a_batch_generate": False,
             },
             1.0,
         ),
@@ -360,13 +446,14 @@ def test_monotonicity_nguyen(
                 "perturb_baseline": "mean",
                 "features_in_step": 28,
                 "normalise": True,
-                "disable_warnings": False,
                 "explain_func": explain,
                 "method": "Saliency",
                 "abs": True,
                 "img_size": 28,
                 "nr_channels": 1,
                 "max_steps_per_input": 2,
+                "disable_warnings": False,
+                "display_progressbar": False,
             },
             {"min": 0.0, "max": 1.0},
         ),
@@ -377,11 +464,12 @@ def test_monotonicity_nguyen(
                 "perturb_baseline": "mean",
                 "features_in_step": 14,
                 "normalise": False,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
             },
             {"min": 0.0, "max": 1.0},
         ),
@@ -392,11 +480,12 @@ def test_monotonicity_nguyen(
                 "perturb_baseline": "random",
                 "features_in_step": 56,
                 "normalise": False,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
             },
             {"min": 0.0, "max": 1.0},
         ),
@@ -407,15 +496,34 @@ def test_monotonicity_nguyen(
                 "perturb_baseline": "random",
                 "features_in_step": 112,
                 "normalise": False,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
                 "a_batch_generate": False,
             },
             {"min": 0.0, "max": 1.0},
         ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "perturb_baseline": "mean",
+                "features_in_step": 28,
+                "normalise": True,
+                "explain_func": explain,
+                "method": "Saliency",
+                "abs": True,
+                "img_size": 28,
+                "nr_channels": 1,
+                "max_steps_per_input": 2,
+                "disable_warnings": True,
+                "display_progressbar": True,
+            },
+            {"min": 0.0, "max": 1.0},
+        ),
     ],
 )
 def test_pixel_flipping(
@@ -463,11 +571,12 @@ def test_pixel_flipping(
                 "patch_size": 7,
                 "normalise": True,
                 "order": "morf",
-                "disable_warnings": False,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": False,
+                "display_progressbar": False,
             },
             {"min": -1, "max": 1.0},
         ),
@@ -479,15 +588,50 @@ def test_pixel_flipping(
                 "patch_size": 7,
                 "normalise": True,
                 "order": "random",
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
                 "a_batch_generate": False,
             },
             {"min": -1, "max": 1.0},
         ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "perturb_baseline": "mean",
+                "patch_size": 7,
+                "normalise": True,
+                "order": "morf",
+                "explain_func": explain,
+                "method": "Saliency",
+                "img_size": 28,
+                "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
+            },
+            {"min": -1, "max": 1.0},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "perturb_baseline": "mean",
+                "patch_size": 7,
+                "normalise": True,
+                "order": "morf",
+                "explain_func": explain,
+                "method": "Saliency",
+                "img_size": 28,
+                "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": True,
+            },
+            {"min": -1, "max": 1.0},
+        ),
     ],
 )
 def test_region_segmentation(
@@ -532,13 +676,14 @@ def test_region_segmentation(
                 "perturb_baseline": "mean",
                 "patch_size": 7,
                 "normalise": True,
-                "disable_warnings": False,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
                 "abs": True,
                 "max_steps_per_input": 2,
+                "disable_warnings": False,
+                "display_progressbar": False,
             },
             {"min": 0.0, "max": 1.0},
         ),
@@ -549,11 +694,12 @@ def test_region_segmentation(
                 "perturb_baseline": "random",
                 "patch_size": 4,
                 "normalise": True,
-                "disable_warnings": False,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
                 "a_batch_generate": False,
             },
             {"min": 0.0, "max": 1.0},
@@ -565,11 +711,30 @@ def test_region_segmentation(
                 "perturb_baseline": "random",
                 "patch_size": 4,
                 "normalise": True,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Gradient",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
+            },
+            {"min": 0.0, "max": 1.0},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "perturb_baseline": "mean",
+                "patch_size": 7,
+                "normalise": True,
+                "explain_func": explain,
+                "method": "Saliency",
+                "img_size": 28,
+                "nr_channels": 1,
+                "abs": True,
+                "max_steps_per_input": 2,
+                "disable_warnings": True,
+                "display_progressbar": True,
             },
             {"min": 0.0, "max": 1.0},
         ),
@@ -621,12 +786,13 @@ def test_selectivity(
                 "features_in_step": 28,
                 "similarity_func": correlation_spearman,
                 "normalise": True,
-                "disable_warnings": False,
                 "explain_func": explain,
                 "method": "Saliency",
                 "abs": True,
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": False,
+                "display_progressbar": False,
             },
             {"min": -1.0, "max": 1.0},
         ),
@@ -639,11 +805,12 @@ def test_selectivity(
                 "features_in_step": 28,
                 "similarity_func": correlation_spearman,
                 "normalise": True,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
             },
             {"min": -1.0, "max": 1.0},
         ),
@@ -656,13 +823,33 @@ def test_selectivity(
                 "features_in_step": 28,
                 "similarity_func": correlation_spearman,
                 "normalise": True,
-                "disable_warnings": True,
                 "explain_func": explain,
                 "method": "Gradient",
                 "img_size": 28,
                 "nr_channels": 1,
-                "a_batch_generate": False,
                 "max_steps_per_input": 2,
+                "disable_warnings": True,
+                "display_progressbar": False,
+                "a_batch_generate": False,
+            },
+            {"min": -1.0, "max": 1.0},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "perturb_baseline": "black",
+                "n_max_percentage": 0.9,
+                "features_in_step": 28,
+                "similarity_func": correlation_spearman,
+                "normalise": True,
+                "explain_func": explain,
+                "method": "Saliency",
+                "abs": True,
+                "img_size": 28,
+                "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": True,
             },
             {"min": -1.0, "max": 1.0},
         ),
@@ -713,12 +900,30 @@ def test_sensitivity_n(
                 "perturb_baseline": "mean",
                 "segmentation_method": "slic",
                 "normalise": True,
-                "disable_warnings": True,
+                "explain_func": explain,
+                "method": "Saliency",
+                "img_size": 28,
+                "nr_channels": 1,
+                "max_steps_per_input": 2,
+                "disable_warnings": False,
+                "display_progressbar": False,
+            },
+            {"min": 0.0, "max": 1.0},
+        ),
+        (
+            lazy_fixture("load_mnist_model"),
+            lazy_fixture("load_mnist_images"),
+            {
+                "perturb_baseline": "mean",
+                "segmentation_method": "slic",
+                "normalise": True,
                 "explain_func": explain,
                 "method": "Saliency",
                 "abs": True,
                 "img_size": 28,
                 "nr_channels": 1,
+                "disable_warnings": True,
+                "display_progressbar": False,
                 "a_batch_generate": False,
             },
             {"min": 0.0, "max": 1.0},
@@ -730,12 +935,13 @@ def test_sensitivity_n(
                 "perturb_baseline": "mean",
                 "segmentation_method": "slic",
                 "normalise": True,
-                "disable_warnings": False,
                 "explain_func": explain,
                 "method": "Saliency",
                 "img_size": 28,
                 "nr_channels": 1,
                 "max_steps_per_input": 2,
+                "disable_warnings": True,
+                "display_progressbar": True,
             },
             {"min": 0.0, "max": 1.0},
         ),
